API reference
=============

.. automodule:: pgmuvi
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    pgmuvi.lightcurve
    pgmuvi.gps
    pgmuvi.trainers